@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Maildir;
 # ABSTRACT: deliver mail to a maildir on disk
-$Email::Sender::Transport::Maildir::VERSION = '1.300016';
+$Email::Sender::Transport::Maildir::VERSION = '1.300020';
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -75,8 +75,12 @@ sub send_email {
   my $dupe = Email::Abstract->new(\do { $email->as_string });
 
   if ($self->add_envelope_headers) {
-    $dupe->set_header('X-Email-Sender-From' => $env->{from});
-    $dupe->set_header('X-Email-Sender-To'   => @{ $env->{to} });
+    $dupe->set_header('X-Email-Sender-From' =>
+      (defined $env->{from} ? $env->{from} : '-'),
+    );
+
+    my @to = grep {; defined } @{ $env->{to} };
+    $dupe->set_header('X-Email-Sender-To'   => (@to ? @to : '-'));
   }
 
   $self->_ensure_maildir_exists;
@@ -182,7 +186,7 @@ Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
 
 =head1 VERSION
 
-version 1.300016
+version 1.300020
 
 =head1 DESCRIPTION
 
@@ -210,7 +214,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
