@@ -1,6 +1,6 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300014';
+$Email::Sender::Transport::SMTP::VERSION = '1.300020';
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -9,6 +9,8 @@ use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
 use MooX::Types::MooseLike::Base qw(Bool Int Str);
 
+use utf8 (); # See below. -- rjbs, 2015-05-14
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This transport is used to send email over SMTP, either with or without secure
@@ -34,6 +36,12 @@ use MooX::Types::MooseLike::Base qw(Bool Int Str);
 #pod
 #pod =cut
 
+sub BUILD {
+  my ($self) = @_;
+  Carp::croak("do not pass port number to SMTP transport in host, use port parameter")
+    if $self->host =~ /:/;
+}
+
 has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
 has ssl  => (is => 'ro', isa => Bool, default => sub { 0 });
 has port => (
@@ -203,6 +211,17 @@ sub send_email {
 
   while (length $msg_string) {
     my $next_hunk = substr $msg_string, 0, $hunk_size, '';
+
+    # For the need to downgrade, see
+    #   https://rt.cpan.org/Ticket/Display.html?id=104433
+    #
+    # The ||0 is there because when we've mocked Net::SMTP, there is no
+    # version.  We can't get the ->VERSION call to hit the mock, because we get
+    # the mock from ->new.  We don't want to create a new SMTP just to get the
+    # version, and we can't rely on $smtp being a Net::SMTP object.
+    # -- rjbs, 2015-08-10
+    utf8::downgrade($next_hunk) if (Net::SMTP->VERSION || 0) < 3.07;
+
     $smtp->datasend($next_hunk) or $FAULT->("error at during DATA");
   }
 
@@ -261,7 +280,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300014
+version 1.300020
 
 =head1 DESCRIPTION
 
@@ -314,7 +333,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
